@@ -5,6 +5,7 @@ import logging
 
 from pyes import ES
 from pyes.managers import Indices
+
 from trytond.config import config
 from trytond.exceptions import UserError
 from trytond.i18n import gettext
@@ -145,8 +146,7 @@ class Configuration(ModelSingleton, ModelSQL, ModelView):
 
     @classmethod
     def __setup__(cls):
-        super(Configuration, cls).__setup__()
-
+        super().__setup__()
         # allow buttons
         cls._buttons.update({
             'update_settings': {},
@@ -156,7 +156,7 @@ class Configuration(ModelSingleton, ModelSQL, ModelView):
     @classmethod
     def validate(cls, records):
         "Validate the records"
-        super(Configuration, cls).validate(records)
+        super().validate(records)
         for record in records:
             record.check_valid_json()
 
